<?php
require_once __DIR__.'/util.php';
require_once __DIR__.'/../../api/magellan.php';
require_once __DIR__.'/../../api/lib/request.php';
require_once __DIR__.'/../../api/lib/response.php';
require_once __DIR__.'/../../api/lib/error_response.php';

class MagellanTest extends PHPUnit_Framework_TestCase {
	public function test_handle_request_ok() {
		$request = new Api_Request("/api/magellan/v1/jobs");
		$mock = $this->getMockBuilder('\Magellan')->setMethods(array('curl_request'))->getMock();
		$mock->expects($this->once())
			->method('curl_request')
			->with($this->equalTo($request), $this->equalTo('dummy/v1/jobs'), $this->equalTo(''))
			->will($this->returnValue(array(
				'response' => '{"not":"tested here"}',
				'http_code' => 200,
				'content_type' => 'application/json'
			)));

		$response = $mock->handle_request($request);

		$this->assertInstanceOf('Api_Response', $response);
		$this->assertSame(200, $response->get_code());
	}

	public function test_handle_request_fail() {
		$request = new Api_Request('/api/magellan/v1/jobs');
		$mock = $this->getMockBuilder('\Magellan')->setMethods(array('curl_request'))->getMock();
		$mock->expects($this->once())
			->method('curl_request')
			->with($this->equalTo($request), $this->equalTo('dummy/v1/jobs'), $this->equalTo(''))
			->will($this->returnValue(array(
				'response' => '',
				'http_code' => 0,
				'content_type' => 'application/json'
			)));

		$this->setExpectedException('Api_Error_Response', '', 502);

		$mock->handle_request($request);
	}
}
